@@ -19,6 +19,7 @@ import importlib
 import importlib.metadata
 import logging
 import os.path
+import sys
 from collections.abc import Iterable, Mapping, MutableMapping
 from typing import Any, List, Optional
 
@@ -46,7 +47,12 @@ PRERUN_ROW_LIMIT = 100
 def get_plugin_classes():
     plugin_classes = set()
     for ep in importlib.metadata.entry_points(group="countess_plugins"):
-        plugin_class = ep.load()
+        try:
+            plugin_class = ep.load()
+        except (ModuleNotFoundError, ImportError, NotImplementedError) as exc:
+            logging.warning("%s could not be loaded: %s", ep, exc)
+            continue
+
         if issubclass(plugin_class, BasePlugin):
             plugin_classes.add(plugin_class)
         else:
@@ -68,12 +74,15 @@ class BasePlugin:
     as plugins."""
 
     name: str = ""
-    title: str = ""
     description: str = ""
-    version: str = "0.0.0"
+    link: Optional[str] = None
 
     parameters: MutableMapping[str, BaseParam] = {}
 
+    @property
+    def version(self) -> str:
+        return sys.modules[self.__module__].VERSION
+
     def __init__(self, plugin_name=None):
         # Parameters store the actual values they are set to, so we copy them
         # so that if the same plugin is used twice in a pipeline it will have
@@ -154,10 +163,6 @@ class FileInputMixin:
     file_types = [("Any", "*")]
     file_params: MutableMapping[str, BaseParam] = {}
 
-    parameters: MutableMapping[str, BaseParam] = {
-        "files": FileArrayParam("Files", FileParam("File"))
-    }
-
     def prepare(self, obj: Any, logger: Logger) -> bool:
         if obj is not None:
             logger.error("FileInputMixin doesn't take inputs")
@@ -212,8 +217,8 @@ class DaskBasePlugin(BasePlugin):
     ):
         raise NotImplementedError(f"{self.__class__}.run()")
 
-class DaskTransformPlugin(DaskBasePlugin):
 
+class DaskTransformPlugin(DaskBasePlugin):
     input_columns: list[str] = []
 
     def prepare_dask(self, df: dd.DataFrame | pd.DataFrame, logger: Logger):
