@@ -3,6 +3,7 @@ import random
 import re
 import sys
 import tkinter as tk
+import webbrowser
 from enum import Enum, IntFlag
 from functools import partial
 from tkinter import filedialog, messagebox, ttk
@@ -12,11 +13,7 @@ import dask.dataframe as dd
 import pandas as pd  # type: ignore
 
 from countess import VERSION
-from countess.core.config import (
-    export_config_graphviz,
-    read_config,
-    write_config,
-)
+from countess.core.config import export_config_graphviz, read_config, write_config
 from countess.core.logger import ConsoleLogger
 from countess.core.pipeline import PipelineGraph, PipelineNode
 from countess.core.plugins import get_plugin_classes
@@ -73,6 +70,8 @@ class TkCursors(Enum):
     PLUS = "plus"
 
 
+UNICODE_INFO = "\u2139"
+
 DraggableMixinState = Enum(
     "DraggableMixinState", ["READY", "DRAG_WAIT", "LINK_WAIT", "DRAGGING", "LINKING"]
 )
@@ -264,12 +263,13 @@ class PluginChooserFrame(tk.Frame):
         label_frame.grid(row=1, column=0, sticky=tk.EW, padx=10, pady=10)
 
         for n, plugin_class in enumerate(plugin_classes):
+            label_text = plugin_class.description.split('. ')[0]
             ttk.Button(
                 label_frame,
                 text=plugin_class.name,
                 command=lambda plugin_class=plugin_class: callback(plugin_class),
             ).grid(row=n + 1, column=0, sticky=tk.EW)
-            ttk.Label(label_frame, text=plugin_class.title).grid(
+            ttk.Label(label_frame, text=label_text).grid(
                 row=n + 1, column=1, sticky=tk.W, padx=10
             )
 
@@ -517,6 +517,7 @@ class GraphWrapper:
         new_node = PipelineNode(name=f"NEW {len(self.graph.nodes)+1}", position=position)
         self.graph.add_node(new_node)
         self.labels[new_node] = self.label_for_node(new_node)
+        self.labels[new_node].update()
         self.lines[new_node] = {}
         if select:
             self.highlight_node(new_node)
@@ -603,20 +604,39 @@ class ConfiguratorWrapper:
 
         self.name_var = tk.StringVar(self.frame, value=node.name)
         tk.Entry(self.frame, textvariable=self.name_var, font=("TkHeadingFont", 14, "bold")).grid(
-            row=0, sticky=tk.EW, padx=10, pady=5
+            row=0, columnspan=2, sticky=tk.EW, padx=10, pady=5
         )
         self.name_var.trace("w", self.name_changed_callback)
 
+        self.label = tk.Label(self.frame, justify=tk.LEFT, wraplength=500)
+        self.label.grid(sticky=tk.EW, row=1, padx=10, pady=5)
+        self.label.bind("<Configure>", self.on_label_configure)
+
+        self.notes_widget = tk.Text(self.frame, height=5)
+        self.notes_widget.insert("1.0", node.notes or "")
+        self.notes_widget.bind("<<Modified>>", self.notes_modified_callback)
+
         self.logger_subframe = LoggerFrame(self.frame)
         self.logger = self.logger_subframe.get_logger(node.name)
 
         self.show_config_subframe()
-        self.show_preview_subframe()
+        if self.node.plugin:
+            self.show_preview_subframe()
 
     def show_config_subframe(self):
         if self.config_subframe:
             self.config_subframe.destroy()
         if self.node.plugin:
+            self.label["text"] = "%s %s — %s" % (
+                self.node.plugin.name,
+                self.node.plugin.version,
+                self.node.plugin.description,
+            )
+            if self.node.plugin.link:
+                tk.Button(
+                    self.frame, text=UNICODE_INFO, fg="blue", command=self.on_info_button_press
+                ).grid(row=1, column=1, sticky=tk.SE, padx=10)
+            self.notes_widget.grid(row=2, columnspan=2, sticky=tk.EW, padx=10, pady=5)
             self.configurator = PluginConfigurator(
                 self.frame, self.node.plugin, self.config_change_callback
             )
@@ -625,7 +645,13 @@ class ConfiguratorWrapper:
             self.config_subframe = PluginChooserFrame(
                 self.frame, "Choose Plugin", self.choose_plugin
             )
-        self.config_subframe.grid(row=1, sticky=tk.NSEW)
+        self.config_subframe.grid(row=3, columnspan=2, sticky=tk.NSEW)
+
+    def on_label_configure(self, *_):
+        self.label["wraplength"] = self.label.winfo_width() - 20
+
+    def on_info_button_press(self, *_):
+        webbrowser.open_new_tab(self.node.plugin.link)
 
     def show_preview_subframe(self):
         if self.preview_subframe:
@@ -645,12 +671,13 @@ class ConfiguratorWrapper:
             text.grid(sticky=tk.NSEW)
         else:
             self.preview_subframe = tk.Frame(self.frame)
-            tk.Label(self.preview_subframe, text="no result").grid(sticky=tk.NSEW)
+            self.preview_subframe.columnconfigure(0, weight=1)
+            tk.Label(self.preview_subframe, text="no result").grid(sticky=tk.EW)
 
-        self.preview_subframe.grid(row=2, column=0, sticky=tk.NSEW)
+        self.preview_subframe.grid(row=4, columnspan=2, sticky=tk.NSEW)
 
         if self.logger.count > 0:
-            self.logger_subframe.grid(row=3, sticky=tk.NSEW)
+            self.logger_subframe.grid(row=5, columnspan=2, sticky=tk.NSEW)
         else:
             self.logger_subframe.grid_forget()
 
@@ -659,6 +686,10 @@ class ConfiguratorWrapper:
         self.node.name = name
         self.change_callback(self.node)
 
+    def notes_modified_callback(self, *_):
+        self.node.notes = self.notes_widget.get("1.0", tk.END)
+        self.notes_widget.edit_modified(False)
+
     def config_change_callback(self, *_):
         self.node.mark_dirty()
         if self.config_change_task:
@@ -703,17 +734,12 @@ class ConfiguratorWrapper:
 
 
 class ButtonMenu:  # pylint: disable=R0903
-    def __init__(self, tk_parent, buttons, label):
+    def __init__(self, tk_parent, buttons):
         self.frame = tk.Frame(tk_parent)
         for button_number, (button_label, button_command) in enumerate(buttons):
             tk.Button(self.frame, text=button_label, command=button_command).grid(
                 row=0, column=button_number, sticky=tk.EW
             )
-
-        tk.Label(self.frame, text=label, font=("TkHeadingFont", 14, "bold")).grid(
-            row=0, column=len(buttons), sticky=tk.E
-        )
-        self.frame.columnconfigure(len(buttons), weight=1)
         self.frame.grid(sticky=tk.NSEW)
 
 
@@ -740,7 +766,6 @@ class MainWindow:
                 ("Run", self.program_run),
                 ("Exit", self.program_exit),
             ],
-            f"CountESS {VERSION}",
         )
 
         self.frame = tk.Frame(tk_parent)
@@ -751,8 +776,10 @@ class MainWindow:
         self.subframe.columnconfigure(0, weight=1)
         self.subframe.rowconfigure(0, weight=0)
         self.subframe.rowconfigure(1, weight=0)
-        self.subframe.rowconfigure(2, weight=1)
-        self.subframe.rowconfigure(3, weight=0)
+        self.subframe.rowconfigure(2, weight=0)
+        self.subframe.rowconfigure(3, weight=1)
+        self.subframe.rowconfigure(4, weight=2)
+        self.subframe.rowconfigure(5, weight=0)
 
         self.frame.bind("<Configure>", self.on_frame_configure, add=True)
 
