@@ -21,9 +21,9 @@ class DaskPivotPlugin(DaskTransformPlugin):
     """Groups a Dask Dataframe by an arbitrary column and rolls up rows"""
 
     name = "Pivot Tool"
-    title = "Pivot Tool"
-    description = "..."
+    description = "Groups a dataframe and pivots column values into columns"
     version = VERSION
+    link = "https://countess-project.github.io/CountESS/plugins/#pivot-tool"
 
     parameters = {
         "index": ArrayParam("Index By", ColumnChoiceParam("Column")),
